
Changelog
=========

0.8.1 (2018-12-03)
------------------

- Bugfix in GenomicIndexer.create_from_region

0.8.0 (2018-12-02)
------------------

- Improved test coverage
- Improved linter issues
- Bugs fixed
- Improved documentation for scorers
- Removed kwargs for scorers and exporters
- Adapted exporters to classes


0.7.0 (2018-12-01)
------------------

- First public version
